Learn R Programming

modisfast (version 2.0.0)

modisfast-package: modisfast: Fast and Efficient Access to MODIS Earth Observation Data

Description

logo

Programmatic interface to several NASA Earth Observation 'OPeNDAP' servers (Open-source Project for a Network Data Access Protocol) (https://www.opendap.org/). Allows for easy downloads of MODIS subsets, as well as other Earth Observation datacubes, in a time-saving and efficient way : by sampling it at the very downloading phase (spatially, temporally and dimensionally).

Arguments

Author

Maintainer: Paul Taconet [email protected] (ORCID) [copyright holder]

Authors:

Other contributors:

  • Nicolas Moiroux [email protected] (ORCID) [funder]

  • French National Research Institute for Sustainable Development, IRD [funder]

See Also